@@ -10,7 +10,6 @@
 
 #pragma once
 
-#include "helper/searchcollectionhelper.h"
 #include "korganizerprivate_export.h"
 
 #include "interfaces/korganizer/calendarviewbase.h"
@@ -20,9 +19,12 @@
 #include <KCalendarCore/Visitor>
 
 #include <Akonadi/ITIPHandler>
+#include <Akonadi/SearchCollectionHelper>
 
 #include <CalendarSupport/MessageWidget>
 
+#include <list>
+
 class DateChecker;
 class DateNavigator;
 class DateNavigatorContainer;
@@ -83,7 +85,7 @@ public:
   @short main calendar view widget
   @author Cornelius Schumacher
 */
-class KORGANIZERPRIVATE_EXPORT CalendarView : public KOrg::CalendarViewBase, public Akonadi::ETMCalendar::CalendarObserver
+class KORGANIZERPRIVATE_EXPORT CalendarView : public KOrg::CalendarViewBase, public KCalendarCore::Calendar::CalendarObserver
 {
     Q_OBJECT
 public:
@@ -112,6 +114,10 @@ public:
     void setCalendar(const Akonadi::ETMCalendar::Ptr &);
     Akonadi::ETMCalendar::Ptr calendar() const override;
 
+    QList<Akonadi::CollectionCalendar::Ptr> enabledCalendars() const;
+
+    Akonadi::CollectionCalendar::Ptr calendarForCollection(const Akonadi::Collection &collection) override;
+
     void showMessage(const QString &message, KMessageWidget::MessageType);
 
     Akonadi::History *history() const;
@@ -158,8 +164,8 @@ public:
      */
     void updateHighlightModes();
 
-    Q_REQUIRED_RESULT QDate startDate() override;
-    Q_REQUIRED_RESULT QDate endDate() override;
+    [[nodiscard]] QDate startDate() override;
+    [[nodiscard]] QDate endDate() override;
 
     KOrg::BaseView *currentView() const;
     void addView(KOrg::BaseView *) override;
@@ -175,26 +181,26 @@ public:
      * Returns the item selected in the current view (or an invalid one if none selected)
      * @reimp
      */
-    Q_REQUIRED_RESULT Akonadi::Item currentSelection() override;
+    [[nodiscard]] Akonadi::Item currentSelection() override;
 
     /**
      * Returns a pointer to the incidence selected in the current view. If there
      * is no selection, return the selected todo from the todo list on the left.
      */
-    Q_REQUIRED_RESULT Akonadi::Item selectedIncidence();
+    [[nodiscard]] Akonadi::Item selectedIncidence();
 
     /**
      * Returns true if there's a filter applied.
      */
-    Q_REQUIRED_RESULT bool isFiltered() const;
+    [[nodiscard]] bool isFiltered() const;
 
     /**
      * Returns the name of the current filter.
      */
-    Q_REQUIRED_RESULT QString currentFilterName() const;
+    [[nodiscard]] QString currentFilterName() const;
 
     /** query if the calendar is read-only. */
-    Q_REQUIRED_RESULT bool isReadOnly() const;
+    [[nodiscard]] bool isReadOnly() const;
 
 Q_SIGNALS:
     /** when change is made to options dialog, the topwidget will catch this
@@ -244,6 +250,9 @@ Q_SIGNALS:
     void filtersUpdated(const QStringList &, int);
     void filterChanged();
 
+    void calendarAdded(const Akonadi::CollectionCalendar::Ptr &calendar);
+    void calendarRemoved(const Akonadi::CollectionCalendar::Ptr &calendar);
+
 public Q_SLOTS:
     /** options dialog made a changed to the configuration. we catch this
      *  and notify all widgets which need to update their configuration. */
@@ -306,10 +315,8 @@ public Q_SLOTS:
     /**
       Show an incidence in context, given its uid.
       @param uid the iCal uid of the incidence to show.
-      @param activeDate The active date is used to calculate the actual date of
-                        the selected incidence in case of recurring incidences.
     */
-    void showIncidenceByUid(const QString &uid, QDate activeDate = {});
+    void showIncidenceByUid(const QString &uid);
 
     /** Create an editor for the supplied incidence. It calls the correct editXXX method*/
     bool editIncidence(const Akonadi::Item &item, bool isCounter = false) override;
@@ -432,10 +439,8 @@ public Q_SLOTS:
 
     void slotModifyFinished(int changeId, const Akonadi::Item &item, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
 
-    void slotDeleteFinished(int changeId,
-                            const QVector<Akonadi::Item::Id> &itemIdList,
-                            Akonadi::IncidenceChanger::ResultCode resultCode,
-                            const QString &errorString);
+    void
+    slotDeleteFinished(int changeId, const QList<Akonadi::Item::Id> &itemIdList, Akonadi::IncidenceChanger::ResultCode resultCode, const QString &errorString);
 
     void startMultiModify(const QString &text);
     void endMultiModify();
@@ -593,6 +598,9 @@ public Q_SLOTS:
      */
     void changeFullView(bool fullView);
 
+    void collectionSelected(const Akonadi::Collection &collection);
+    void collectionDeselected(const Akonadi::Collection &collection);
+
 protected Q_SLOTS:
     /**
      * Select a view or adapt the current view to display the specified dates.
@@ -700,6 +708,12 @@ private:
     QList<CalendarViewExtension *> mExtensions;
 
     Akonadi::ETMCalendar::Ptr mCalendar;
+    QList<Akonadi::CollectionCalendar::Ptr> mEnabledCalendars;
+    // Actual linked-list implementation - we don't expect to ever have that many calendars
+    // enabled that e.g. QMap/QHash would be substantially faster over looping over the list.
+    // The advantage of the list is that on each iteration we can quickly remove and stale
+    // weak pointers.
+    std::list<QWeakPointer<Akonadi::CollectionCalendar>> mCalendars;
 
     DateNavigator *mDateNavigator = nullptr;
     DateChecker *mDateChecker = nullptr;
@@ -728,5 +742,5 @@ private:
     Akonadi::CalendarClipboard *mCalendarClipboard = nullptr;
     AkonadiCollectionView *mETMCollectionView = nullptr;
 
-    SearchCollectionHelper mSearchCollectionHelper;
+    Akonadi::SearchCollectionHelper mSearchCollectionHelper;
 };
