@@ -8,11 +8,8 @@
 */
 
 #pragma once
-#include "kcmutils_version.h"
 #include <KCModule>
-#if KCMUTILS_VERSION >= QT_VERSION_CHECK(5, 240, 0)
 #include <KPluginMetaData>
-#endif
 class QLabel;
 class QPushButton;
 class QTreeWidget;
@@ -22,11 +19,7 @@ class KCMDesignerFields : public KCModule
 {
     Q_OBJECT
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KCMDesignerFields(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
-#else
-    explicit KCMDesignerFields(QObject *parent, const KPluginMetaData &data, const QVariantList &args = QVariantList());
-#endif
+    explicit KCMDesignerFields(QObject *parent, const KPluginMetaData &data = {});
 
     void load() override;
     void save() override;
@@ -35,7 +28,7 @@ public:
 protected:
     void loadUiFiles();
     void loadActivePages(const QStringList &);
-    Q_REQUIRED_RESULT QStringList saveActivePages();
+    [[nodiscard]] QStringList saveActivePages();
 
     virtual QString localUiDir() = 0;
     virtual QString uiPath() = 0;
