@@ -7,7 +7,6 @@
 */
 
 #pragma once
-#include "kcmutils_version.h"
 #include "ui_apptsummaryconfig_base.h"
 #include <KCModule>
 
@@ -16,11 +15,7 @@ class KCMApptSummary : public KCModule, public Ui::ApptSummaryConfig_Base
     Q_OBJECT
 
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KCMApptSummary(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
-#else
-    explicit KCMApptSummary(QObject *parent, const KPluginMetaData &data, const QVariantList &args = QVariantList());
-#endif
+    explicit KCMApptSummary(QObject *parent, const KPluginMetaData &data);
 
     void load() override;
     void save() override;
