@@ -17,19 +17,10 @@
 
 K_PLUGIN_CLASS_WITH_JSON(KCMSDSummary, "kcmsdsummary.json")
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-KCMSDSummary::KCMSDSummary(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-#else
-KCMSDSummary::KCMSDSummary(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
-#endif
+KCMSDSummary::KCMSDSummary(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    setupUi(this);
-#else
     setupUi(widget());
-#endif
 
     customDaysChanged(7);
 
@@ -50,22 +41,14 @@ KCMSDSummary::KCMSDSummary(QObject *parent, const KPluginMetaData &data, const Q
 
     connect(mShowMineOnly, &QCheckBox::stateChanged, this, &KCMSDSummary::modified);
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    KAcceleratorManager::manage(this);
-#else
     KAcceleratorManager::manage(widget());
-#endif
 
     load();
 }
 
 void KCMSDSummary::modified()
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(true);
-#else
     markAsChanged();
-#endif
 }
 
 void KCMSDSummary::buttonClicked(int id)
@@ -82,7 +65,7 @@ void KCMSDSummary::load()
 {
     KConfig config(QStringLiteral("kcmsdsummaryrc"));
 
-    KConfigGroup group = config.group("Days");
+    KConfigGroup group = config.group(QStringLiteral("Days"));
     const int days = group.readEntry("DaysToShow", 7);
     if (days == 1) {
         mDateTodayButton->setChecked(true);
@@ -94,7 +77,7 @@ void KCMSDSummary::load()
         mCustomDays->setEnabled(true);
     }
 
-    group = config.group("Show");
+    group = config.group(QStringLiteral("Show"));
 
     mShowBirthdaysFromKABBox->setChecked(group.readEntry("BirthdaysFromContacts", true));
     mShowBirthdaysFromCalBox->setChecked(group.readEntry("BirthdaysFromCalendar", true));
@@ -106,21 +89,17 @@ void KCMSDSummary::load()
 
     mShowSpecialsFromCalBox->setChecked(group.readEntry("SpecialsFromCalendar", true));
 
-    group = config.group("Groupware");
+    group = config.group(QStringLiteral("Groupware"));
     mShowMineOnly->setChecked(group.readEntry("ShowMineOnly", false));
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(false);
-#else
     setNeedsSave(false);
-#endif
 }
 
 void KCMSDSummary::save()
 {
     KConfig config(QStringLiteral("kcmsdsummaryrc"));
 
-    KConfigGroup group = config.group("Days");
+    KConfigGroup group = config.group(QStringLiteral("Days"));
 
     int days;
     if (mDateTodayButton->isChecked()) {
@@ -132,7 +111,7 @@ void KCMSDSummary::save()
     }
     group.writeEntry("DaysToShow", days);
 
-    group = config.group("Show");
+    group = config.group(QStringLiteral("Show"));
 
     group.writeEntry("BirthdaysFromContacts", mShowBirthdaysFromKABBox->isChecked());
     group.writeEntry("BirthdaysFromCalendar", mShowBirthdaysFromCalBox->isChecked());
@@ -144,15 +123,11 @@ void KCMSDSummary::save()
 
     group.writeEntry("SpecialsFromCalendar", mShowSpecialsFromCalBox->isChecked());
 
-    group = config.group("Groupware");
+    group = config.group(QStringLiteral("Groupware"));
     group.writeEntry("ShowMineOnly", mShowMineOnly->isChecked());
 
     group.sync();
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(false);
-#else
     setNeedsSave(false);
-#endif
 }
 
 void KCMSDSummary::defaults()
@@ -169,11 +144,9 @@ void KCMSDSummary::defaults()
     mShowSpecialsFromCalBox->setChecked(true);
 
     mShowMineOnly->setChecked(false);
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(true);
-#else
     markAsChanged();
-#endif
 }
 
 #include "kcmsdsummary.moc"
+
+#include "moc_kcmsdsummary.cpp"
