@@ -34,8 +34,8 @@
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 
-#include <KUserFeedbackQt6/NotificationPopup>
-#include <KUserFeedbackQt6/Provider>
+#include <KUserFeedback/NotificationPopup>
+#include <KUserFeedback/Provider>
 #endif
 
 KOrganizer::KOrganizer()
@@ -53,7 +53,7 @@ KOrganizer::KOrganizer()
     KOCore::self()->addXMLGUIClient(this, this);
     //  setMinimumSize(600,400);  // make sure we don't get resized too small...
 
-    mCalendarView->setObjectName(QStringLiteral("KOrganizer::CalendarView"));
+    mCalendarView->setObjectName(QLatin1StringView("KOrganizer::CalendarView"));
     setCentralWidget(mCalendarView);
 
     mActionManager = new ActionManager(this, mCalendarView, this, this, false, menuBar(), toolBar());
